==> dokuwiki-2012.01.25b.tgz: dokuwiki/lib/plugins/acl/lang/sk/lang.php <==
<?php
/**
 * Slovak language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Ondrej Vegh <ov@vsieti.sk>
 * @author Michal Mesko <michal.mesko@gmail.com>
 * @author exusik@gmail.com
 * @author Martin Michalek <michalek.dev@gmail.com>
 */
$lang['admin_acl']             = 'Správa zoznamu prístupových práv';
$lang['acl_group']             = 'Skupina';
$lang['acl_user']              = 'Užívateľ';
$lang['acl_perms']             = 'Práva pre';
$lang['page']                  = 'Stránka';
$lang['namespace']             = 'Menný priestor';
$lang['btn_select']            = 'Vybrať';
$lang['p_user_id']             = 'Používateľ <b class="acluser">%s</b> má aktuálne nasledujúce oprávnenia k stránke <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Používateľ <b class="acluser">%s</b> má aktuálne nasledujúce oprávnenia v mennom priestore <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Členovia skupiny <b class="aclgroup">%s</b> majú aktuálne nasledujúce oprávnenia k stránke <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Členovia skupiny <b class="aclgroup">%s</b> majú aktuálne nasledujúce oprávnenia v mennom priestore <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Prosím <b>zadajte používateľa alebo skupinu</b> do formulára zobrazeného vyššie, aby ste mohli prezerať alebo meniť oprávnenia k stránke <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Prosím <b>zadajte používateľa alebo skupinu</b> do formulára zobrazeného vyššie, aby ste mohli prezerať alebo meniť oprávnenia v mennom priestore <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Poznámka: Tieto oprávnenia neboli nastavené explicitne, ale boli odvodené z inej skupiny alebo nadradeného menného priestoru.';
$lang['p_isadmin']             = 'Poznámka: Vybraná skupina alebo používateľ má vždy najvyššie oprávnenia, pretože je vedená/vedený ako správca.';
$lang['p_include']             = 'Vyššie oprávnenia zahŕňajú nižšie. Oprávnenie Vytvoriť, Nahrať a Zmazať sa vzťahujú iba k menným priestorom, nie ku stránkam.';
$lang['current']               = 'Aktuálne pravidlá prístupu (ACL)';
$lang['where']                 = 'Stránka/Menný priestor';
$lang['who']                   = 'Používateľ/Skupina';
$lang['perm']                  = 'Povolenia';
$lang['acl_perm0']             = 'Žiadne';
$lang['acl_perm1']             = 'Čítať';
$lang['acl_perm2']             = 'Zmeniť';
$lang['acl_perm4']             = 'Vytvoriť';
$lang['acl_perm8']             = 'Nahrať súbor';
$lang['acl_perm16']            = 'Zmazať';
$lang['acl_new']               = 'Pridať nový záznam';
$lang['acl_mod']               = 'Upraviť záznam';

==> dokuwiki-2024.02.06.tgz: dokuwiki/lib/plugins/acl/lang/sk/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Ondrej Vegh <ov@vsieti.sk>
 * @author Michal Mesko <michal.mesko@gmail.com>
 * @author exusik <exusik@gmail.com>
 * @author Martin Michalek <michalek.dev@gmail.com>
 */
$lang['admin_acl']             = 'Správa zoznamu prístupových práv';
$lang['acl_group']             = 'Skupina:';
$lang['acl_user']              = 'Užívateľ:';
$lang['acl_perms']             = 'Práva pre';
$lang['page']                  = 'Stránka';
$lang['namespace']             = 'Menný priestor';
$lang['btn_select']            = 'Vybrať';
$lang['p_user_id']             = 'Používateľ <b class="acluser">%s</b> má aktuálne nasledujúce oprávnenia k stránke <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Používateľ <b class="acluser">%s</b> má aktuálne nasledujúce oprávnenia v mennom priestore <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Členovia skupiny <b class="aclgroup">%s</b> majú aktuálne nasledujúce oprávnenia k stránke <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Členovia skupiny <b class="aclgroup">%s</b> majú aktuálne nasledujúce oprávnenia v mennom priestore <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Prosím <b>zadajte používateľa alebo skupinu</b> do formulára zobrazeného vyššie, aby ste mohli prezerať alebo meniť oprávnenia k stránke <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Prosím <b>zadajte používateľa alebo skupinu</b> do formulára zobrazeného vyššie, aby ste mohli prezerať alebo meniť oprávnenia v mennom priestore <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Poznámka: Tieto oprávnenia neboli nastavené explicitne, ale boli odvodené z inej skupiny alebo nadradeného menného priestoru.';
$lang['p_isadmin']             = 'Poznámka: Vybraná skupina alebo používateľ má vždy najvyššie oprávnenia, pretože je vedená/vedený ako správca.';
$lang['p_include']             = 'Vyššie oprávnenia zahŕňajú nižšie. Oprávnenie Vytvoriť, Nahrať a Zmazať sa vzťahujú iba k menným priestorom, nie ku stránkam.';
$lang['current']               = 'Aktuálne pravidlá prístupu (ACL)';
$lang['where']                 = 'Stránka/Menný priestor';
$lang['who']                   = 'Používateľ/Skupina';
$lang['perm']                  = 'Povolenia';
$lang['acl_perm0']             = 'Žiadne';
$lang['acl_perm1']             = 'Čítať';
$lang['acl_perm2']             = 'Zmeniť';
$lang['acl_perm4']             = 'Vytvoriť';
$lang['acl_perm8']             = 'Nahrať súbor';
$lang['acl_perm16']            = 'Zmazať';
$lang['acl_new']               = 'Pridať nový záznam';
$lang['acl_mod']               = 'Upraviť záznam';
